import codepipeline = require('@aws-cdk/aws-codepipeline-api');
import cdk = require('@aws-cdk/cdk');
import { IRepository } from './repository-ref';
/**
 * Common properties for the {@link PipelineSourceAction CodePipeline source Action},
 * whether creating it directly,
 * or through the {@link IRepository#toCodePipelineSourceAction} method.
 */
export interface CommonPipelineSourceActionProps extends codepipeline.CommonActionProps {
    /**
     * The image tag that will be checked for changes.
     *
     * @default 'latest'
     */
    readonly imageTag?: string;
    /**
     * The name of the source's output artifact.
     * CfnOutput artifacts are used by CodePipeline as inputs into other actions.
     *
     * @default a name will be auto-generated
     */
    readonly outputArtifactName?: string;
}
/**
 * Construction properties of {@link PipelineSourceAction}.
 */
export interface PipelineSourceActionProps extends CommonPipelineSourceActionProps {
    /**
     * The repository that will be watched for changes.
     */
    readonly repository: IRepository;
}
/**
 * The ECR Repository source CodePipeline Action.
 */
export declare class PipelineSourceAction extends codepipeline.SourceAction {
    private readonly props;
    constructor(props: PipelineSourceActionProps);
    protected bind(stage: codepipeline.IStage, _scope: cdk.Construct): void;
}
